[−][src]Crate rslint_cli
Macros
| lint_diagnostic | |
| lint_err | Construct a simple linter error and immediately throw it to stderr |
| lint_note | Construct a simple linter note and immediately throw it to stderr |
| lint_warn | Construct a simple linter warning and immediately throw it to stderr |
Structs
| Config | |
| Diagnostic | A diagnostic message that can give information like errors or warnings. |
| ExplanationRunner | A structure for converting user facing markdown docs to ANSI colored terminal explanations. |
| FileWalker | The structure for managing IO to and from the core runner. The walker uses multithreaded IO, spawning a thread for every file being loaded. |
| JsFile | A structure representing either a concrete (in-disk) or virtual (temporary/non-disk) js or mjs file. |
| RulesConfig |
Enums
| JsFileKind | |
| Outcome | The overall result of running a single rule or linting a file. |
| Severity | A severity level for diagnostic messages. |
Constants
| CONFIG_NAME | The name of the config file to search for. |
Functions
| apply_fixes | |
| emit_diagnostic | |
| panic_hook | |
| remap_diagnostics_to_level | Remap each error diagnostic to a warning diagnostic based on the rule's level. this leaves warnings untouched because rules should be able to emit errors and warnings for context without the warnings being remapped to errors. |
| run |